@@ -20,7 +20,7 @@ from pypika import (
     functions,
 )
 from pypika.enums import Comparator, Dialects, JoinType
-from pypika.functions import Extract
+from pypika.functions import Extract, ToDate
 from pypika.queries import QueryBuilder, Selectable
 from pypika.terms import AnalyticFunction, BasicCriterion, Function, Interval, LiteralValue, Term
 from pypika.utils import format_quotes
@@ -39,6 +39,7 @@ from weaverbird.pipeline.conditions import (
 )
 from weaverbird.pipeline.dates import RelativeDate
 from weaverbird.pipeline.pipeline import Pipeline
+from weaverbird.pipeline.steps import ConvertStep, DomainStep
 from weaverbird.pipeline.steps.date_extract import DATE_INFO
 from weaverbird.pipeline.steps.utils.combination import PipelineOrDomainNameOrReference, Reference
 
@@ -55,12 +56,10 @@ if TYPE_CHECKING:
         ArgminStep,
         CompareTextStep,
         ConcatenateStep,
-        ConvertStep,
         CumSumStep,
         CustomSqlStep,
         DateExtractStep,
         DeleteStep,
-        DomainStep,
         DuplicateStep,
         EvolutionStep,
         FillnaStep,
@@ -73,6 +72,7 @@ if TYPE_CHECKING:
         PercentageStep,
         RenameStep,
         ReplaceStep,
+        ReplaceTextStep,
         SelectStep,
         SortStep,
         SplitStep,
@@ -1264,6 +1264,25 @@ class SQLTranslator(ABC):
         query: "QueryBuilder" = self.QUERY_CLS.from_(prev_step_name).select(*selected_col_fields)
         return StepContext(query, [f.alias or f.name for f in selected_col_fields])
 
+    def replacetext(
+        self: Self,
+        *,
+        builder: "QueryBuilder",
+        prev_step_name: str,
+        columns: list[str],
+        step: "ReplaceTextStep",
+    ) -> StepContext:
+        col_field: Field = Table(prev_step_name)[step.search_column]
+
+        replaced_col = functions.Replace(col_field, step.old_str, step.new_str)
+
+        query: "QueryBuilder" = self.QUERY_CLS.from_(prev_step_name).select(
+            *(c for c in columns if c != step.search_column),
+            replaced_col.as_(step.search_column),
+        )
+
+        return StepContext(query, columns)
+
     def replace(
         self: Self,
         *,
@@ -1373,8 +1392,32 @@ class SQLTranslator(ABC):
     ) -> StepContext:
         from pypika.terms import ValueWrapper
 
+        # Since we're using WITH...AS syntax, we add an explicit cast here to provide type
+        # context to the engine. Without that, we might encounter "failed to find conversion
+        # function from "unknown" to text" errors
+        value = step.text
+
+        if isinstance(value, datetime):
+            # ValueWrapper(value) would produce an iso8601 string which
+            # is not properly handled by some backends
+            value_wrapped = ValueWrapper(value.strftime("%Y-%m-%d %H:%M:%S"))
+        else:
+            value_wrapped = ValueWrapper(value)
+
+        if isinstance(value, datetime):
+            value_wrapped = functions.Cast(value_wrapped, self.DATA_TYPE_MAPPING.datetime)
+        elif isinstance(value, int):
+            value_wrapped = functions.Cast(value_wrapped, self.DATA_TYPE_MAPPING.integer)
+        elif isinstance(value, float):
+            value_wrapped = functions.Cast(value_wrapped, self.DATA_TYPE_MAPPING.float)
+        elif isinstance(value, bool):
+            value_wrapped = functions.Cast(value_wrapped, self.DATA_TYPE_MAPPING.boolean)
+        else:
+            value_wrapped = functions.Cast(value_wrapped, self.DATA_TYPE_MAPPING.text)
+
         query: "QueryBuilder" = self.QUERY_CLS.from_(prev_step_name).select(
-            *columns, ValueWrapper(step.text).as_(step.new_column)
+            *columns,
+            value_wrapped.as_(step.new_column),
         )
         return StepContext(query, columns + [step.new_column])
 
@@ -1394,10 +1437,16 @@ class SQLTranslator(ABC):
                     convert_fn = StrToDate
                 case ToDateOp.PARSE_DATE:
                     convert_fn = ParseDate
+                case ToDateOp.DATE_PARSE:
+                    convert_fn = DateParse
                 case ToDateOp.TIMESTAMP:
                     convert_fn = functions.Timestamp
                 case ToDateOp.TO_TIMESTAMP_NTZ:
                     convert_fn = ToTimestampNTZ
+                case ToDateOp.TO_TIMESTAMP:
+                    convert_fn = ToTimestamp
+                case ToDateOp.TO_DATE:
+                    convert_fn = ToDate
                 case _:
                     raise NotImplementedError(f"[{self.DIALECT}] todate has no set operator")
             date_selection = (
@@ -1490,11 +1539,16 @@ class SQLTranslator(ABC):
 
     @classmethod
     def _build_unpivot_col(
-        cls, *, step: "UnpivotStep", quote_char: str | None, secondary_quote_char: str
+        cls,
+        *,
+        step: "UnpivotStep",
+        quote_char: str | None,
+        secondary_quote_char: str,
     ) -> str:
         value_col = format_quotes(step.value_column_name, quote_char)
         unpivot_col = format_quotes(step.unpivot_column_name, quote_char)
         in_cols = ", ".join(format_quotes(col, quote_char) for col in step.unpivot)
+
         if cls.SUPPORT_UNPIVOT:
             return f"UNPIVOT({value_col} FOR {unpivot_col} IN ({in_cols}))"
         in_single_quote_cols = ", ".join(
@@ -1510,14 +1564,32 @@ class SQLTranslator(ABC):
         columns: list[str],
         step: "UnpivotStep",
     ) -> StepContext:
+        # Casting all columns to float first
+        builder_ctx = self.__class__(
+            tables_columns={prev_step_name: columns},
+            # Since we're on a virtual table here (created by WITH...AS), we don't want a schema
+            # name to be prepended
+            db_schema=None,
+            known_instances=self._known_instances,
+        ).get_query_builder(
+            steps=[
+                DomainStep(domain=prev_step_name),
+                ConvertStep(columns=step.unpivot, data_type="float"),
+            ],
+            query_builder=builder,
+        )
+
         unpivot = self._build_unpivot_col(
             step=step,
             quote_char=builder.QUOTE_CHAR,
             secondary_quote_char=builder.SECONDARY_QUOTE_CHAR,
         )
+
+        prev_step_name = builder_ctx.table_name
+
         cols = step.keep + [step.unpivot_column_name] + [step.value_column_name]
         query = LiteralValue(f"{self.QUERY_CLS.from_(prev_step_name).select(*cols)!s} {unpivot}")
-        return StepContext(query, cols)
+        return StepContext(query, cols, builder_ctx.builder)
 
     def uppercase(
         self: Self,
@@ -1561,11 +1633,21 @@ class ParseDate(functions.Function):
         super().__init__("PARSE_DATE", term, date_format, alias=alias)
 
 
+class DateParse(functions.Function):
+    def __init__(self, term: str | Field, date_format: str, alias: str | None = None) -> None:
+        super().__init__("DATE_PARSE", term, date_format, alias=alias)
+
+
 class ToTimestampNTZ(functions.Function):
     def __init__(self, term: str | Field, date_format: str, alias: str | None = None) -> None:
         super().__init__("TO_TIMESTAMP_NTZ", term, date_format, alias=alias)
 
 
+class ToTimestamp(functions.Function):
+    def __init__(self, term: str | Field, date_format: str, alias: str | None = None) -> None:
+        super().__init__("TO_TIMESTAMP", term, date_format, alias=alias)
+
+
 class RegexpMatching(Comparator):
     similar_to = " SIMILAR TO "
     not_similar_to = " NOT SIMILAR TO "
