@@ -1,9 +1,10 @@
 from typing import Any, TypeVar
 
-from pypika.dialects import SnowflakeQueryBuilder
+from pypika.dialects import QueryBuilder, SnowflakeQueryBuilder
 from pypika.enums import Dialects
-from pypika.queries import Query
+from pypika.queries import Query, Selectable
 from pypika.terms import Field, Term
+from pypika.utils import builder, format_quotes
 
 from weaverbird.backends.pypika_translator.dialects import SQLDialect
 from weaverbird.backends.pypika_translator.operators import FromDateOp, RegexOp, ToDateOp
@@ -19,6 +20,10 @@ Self = TypeVar("Self", bound="SQLTranslator")
 class QuotedSnowflakeQueryBuilder(SnowflakeQueryBuilder):
     QUOTE_CHAR = '"'
 
+    @builder
+    def with_(self, selectable: Selectable, name: str) -> "QueryBuilder":
+        return super().with_(selectable, format_quotes(name, self.QUOTE_CHAR))
+
 
 class SnowflakeQuery(Query):
     @classmethod
