@@ -2,12 +2,15 @@ from typing import Literal
 
 from pydantic import Field
 
-from weaverbird.pipeline.steps.utils.base import BaseStep
+from weaverbird.pipeline.steps.utils.base import BaseStep, to_camelcase
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
 from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 
 class ReplaceTextStep(BaseStep):
+    class Config:
+        alias_generator = to_camelcase
+
     name: Literal["replacetext"] = "replacetext"
     search_column: ColumnName
     old_str: str
