@@ -1,10 +1,10 @@
-from typing import Literal, Optional
+from typing import Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.types import ColumnName
 
 
 class ToDateStep(BaseStep):
-    name: Literal['todate'] = 'todate'
+    name: Literal["todate"] = "todate"
     column: ColumnName
-    format: Optional[str]
+    format: str | None
