@@ -1,4 +1,4 @@
-from typing import List, Literal
+from typing import Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
@@ -6,10 +6,10 @@ from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 
 class TopStep(BaseStep):
-    name: Literal['top'] = 'top'
-    groups: List[ColumnName] = []
+    name: Literal["top"] = "top"
+    groups: list[ColumnName] = []
     rank_on: ColumnName
-    sort: Literal['asc', 'desc']
+    sort: Literal["asc", "desc"]
     limit: int
 
 
